## -------------------------------------------------------------- ##
## Import data for real data study
## Called by real-data.R
## -------------------------------------------------------------- ##

library(OpenML)
library(ggplot2)
library(mlbench)
library(survival)
library(MASS)

## Tic Tac Toe
tic_tac_toe <- getOMLDataSet(data.name = "tic-tac-toe", data.version = 1)$data
colnames(tic_tac_toe)[colnames(tic_tac_toe) == "Class"] <- "y"

## MPG
mpg[, sapply(mpg, is.character)] <- lapply(mpg[, sapply(mpg, is.character)], factor)
mpg[, sapply(mpg, is.integer)] <- lapply(mpg[, sapply(mpg, is.integer)], as.numeric)
colnames(mpg)[colnames(mpg) == "class"] <- "y" # Type of car

## Servo
data(Servo)
servo <- Servo
colnames(servo)[colnames(servo) == "Class"] <- "y"

## Rheumatoid arthritis: 250 cases and controls, 500 SNPs
ra_snps <- readRDS("ra_snps.Rds")
cases <- which(ra_snps$y == 1)
controls <- which(ra_snps$y == 0)
idx <- c(sample(cases, 250), sample(controls, 250))
ra_snps <- ra_snps[idx, c(1:2, sample(3:ncol(ra_snps), 500))]

## Splice
splice <- getOMLDataSet(data.name = "splice", data.version = 1)$data
colnames(splice)[colnames(splice) == "Class"] <- "y"
splice[colnames(splice) == "Instance_name"] <- NULL

## Aids
aids <- Aids2
aids <- rbind(aids[aids$T.categ != "hs", ], 
              aids[sample(which(aids$T.categ == "hs"), 100), ])
aids$y <- Surv(aids$death - aids$diag, 1*(aids$status == "D"))
aids$death <- NULL
aids$diag <- NULL
aids$status <- NULL
