## -------------------------------------------------------------- ##
## Absent level study (Fig. 4B)
## -------------------------------------------------------------- ##

library(data.table)
library(simpleRF)
library(ggplot2)
source("problems.R")

set.seed(42)

## Simulate digit data
num_levels <- 10
dat <- digit_data(n = 100, p = 8, 
                  num_levels = num_levels, type = "multiclass" )

## Grow RF
rf <- simpleRF(y ~ ., dat$train, num_trees = 500, unordered_factors = "order_once")

## Recursive function to get the depth of each node
rec_fun <- function(i, depth, tree) {
  if (i <= length(tree$child_nodeIDs)) {
    x <- tree$child_nodeIDs[[i]]
    if (!is.null(x)) {
      if (x[1] <= length(tree$child_nodeIDs)) {
        depth[x[1]] <- i
        depth <- rec_fun(x[1], depth, tree)
      } 
      if (x[1] <= length(tree$child_nodeIDs)) {
        depth[x[2]] <- i
        depth <- rec_fun(x[2], depth, tree)
      } 
    }
  }
  depth
}

## Get number of absent levels
absent <- lapply(rf$trees, function(tree) {
  # Get depth
  depth <- rep(NA, length(tree$child_nodeIDs))
  depth[1] <- 0
  depth <- rec_fun(1, depth, tree)
  
  # Get absent levels
  absent <- sapply(tree$sampleIDs, function(x) {
    num_levels - length(unique(dat$train[x, "X1"]))
  }) 
  
  # Return both
  data.table(cbind(depth, absent[1:length(depth)]))
})

## Get mean number of absent levels per node
absent_all <- rbindlist(absent)
colnames(absent_all) <- c("depth", "absent")
absent_mean <- absent_all[, mean(absent), by = depth]
colnames(absent_mean) <- c("depth", "absent")

## Plot
ggplot(absent_mean, aes(x = depth, y = num_levels - absent)) + 
  geom_point(size = 1) + 
  geom_line() + 
  xlim(c(0, 50)) + 
  xlab("Tree depth") + 
  ylab("Available categories") + 
  scale_y_continuous(breaks = seq(0, 10, by = 2))
ggsave("absent_levels.pdf", width = 3, height = 3)

