## -------------------------------------------------------------- ##
## Tree size study (Fig. 4A)
## -------------------------------------------------------------- ##

library(simpleRF)
library(ggplot2)
library(RColorBrewer)
source("problems.R")

set.seed(42)

## Simulate digit data
dat <- digit_data(n = 100, p = 4, 
                  num_levels = 10, type = "multiclass" )

## Ignore
rf_ignore <- simpleRF(y ~ ., dat$train, num_trees = 50, unordered_factors = "ignore")
nodes_ignore <- sapply(rf_ignore$trees, function(x) {
  length(x$child_nodeIDs)
})

## Order (once)
rf_order <- simpleRF(y ~ ., dat$train, num_trees = 50, unordered_factors = "order_once")
nodes_order <- sapply(rf_order$trees, function(x) {
  length(x$child_nodeIDs)
})

## Compare 
nodes <- rbind(data.frame(unordered_factors = "Ignore", tree_size = nodes_ignore), 
               data.frame(unordered_factors = "Order (once)", tree_size = nodes_order))
ggplot(nodes, aes(x = unordered_factors, y = tree_size, fill = unordered_factors)) + 
  geom_boxplot() + 
  xlab("Nominal predictor method") + 
  ylab("Tree size") + 
  scale_fill_manual(values = brewer.pal(5, name = "Blues")[c(1, 3)]) + 
  theme(legend.position = "none")
ggsave("tree_size.pdf", width = 3, height = 3)
